'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var reactDom = require('react-dom');

var DialogContext =
/*#__PURE__*/
React.createContext({
  node: 'MainContext'
});

var Provider = function Provider(_ref) {
  var children = _ref.children,
      node = _ref.node;
  if (!node) throw new Error('node is required parameter for Modal Provider');
  var context = React.useMemo(function () {
    return {
      node: node
    };
  }, [node]);
  return React.createElement(DialogContext.Provider, {
    value: context
  }, children);
};

var useDialog = function useDialog(defaultState) {
  var _React$useState = React.useState(defaultState || false),
      isOpen = _React$useState[0],
      setOpen = _React$useState[1];

  var open = React.useCallback(function () {
    return setOpen(true);
  }, []);
  var close = React.useCallback(function () {
    return setOpen(false);
  }, []);
  return React.useMemo(function () {
    return {
      isOpen: isOpen,
      open: open,
      close: close
    };
  }, [isOpen]);
};

var Modal = function Modal(_ref) {
  var isOpen = _ref.isOpen,
      children = _ref.children,
      _ref$as = _ref.as,
      as = _ref$as === void 0 ? 'div' : _ref$as;

  var _React$useContext = React.useContext(DialogContext),
      node = _React$useContext.node;

  var _React$useRef = React.useRef(document.createElement(as)),
      modalWrapper = _React$useRef.current;

  React.useEffect(function () {
    if (typeof node !== 'string') node.appendChild(modalWrapper);
    return function () {
      if (typeof node !== 'string') node.removeChild(modalWrapper);
    };
  }, []);
  return isOpen ? reactDom.createPortal(children, modalWrapper) : null;
};

exports.Modal = Modal;
exports.Provider = Provider;
exports.useDialog = useDialog;
//# sourceMappingURL=react-modaly.cjs.development.js.map
