import { createContext, useMemo, createElement, useState, useCallback, useContext, useRef, useEffect } from 'react';
import { createPortal } from 'react-dom';

var DialogContext =
/*#__PURE__*/
createContext({
  node: 'MainContext'
});

var Provider = function Provider(_ref) {
  var children = _ref.children,
      node = _ref.node;
  if (!node) throw new Error('node is required parameter for Modal Provider');
  var context = useMemo(function () {
    return {
      node: node
    };
  }, [node]);
  return createElement(DialogContext.Provider, {
    value: context
  }, children);
};

var useDialog = function useDialog(defaultState) {
  var _React$useState = useState(defaultState || false),
      isOpen = _React$useState[0],
      setOpen = _React$useState[1];

  var open = useCallback(function () {
    return setOpen(true);
  }, []);
  var close = useCallback(function () {
    return setOpen(false);
  }, []);
  return useMemo(function () {
    return {
      isOpen: isOpen,
      open: open,
      close: close
    };
  }, [isOpen]);
};

var Modal = function Modal(_ref) {
  var isOpen = _ref.isOpen,
      children = _ref.children,
      _ref$as = _ref.as,
      as = _ref$as === void 0 ? 'div' : _ref$as;

  var _React$useContext = useContext(DialogContext),
      node = _React$useContext.node;

  var _React$useRef = useRef(document.createElement(as)),
      modalWrapper = _React$useRef.current;

  useEffect(function () {
    if (typeof node !== 'string') node.appendChild(modalWrapper);
    return function () {
      if (typeof node !== 'string') node.removeChild(modalWrapper);
    };
  }, []);
  return isOpen ? createPortal(children, modalWrapper) : null;
};

export { Modal, Provider, useDialog };
//# sourceMappingURL=react-modaly.esm.js.map
